@@ -1,12 +1,15 @@
 """ Defines the configuration for Soil """
-from typing import Optional, NamedTuple
-import logging
-import time
-import os
-from os import getenv
 import json
-import requests
+import logging
+import os
+import time
+from os import getenv
+from typing import NamedTuple, Optional
+
 import jwt
+import requests
+
+from soil import errors
 
 # TODO add windows support
 
@@ -16,14 +19,15 @@ env = getenv("PY_ENV", "development")
 
 def _refresh_token(auth_host: str, refresh_token: str) -> str:
     url = auth_host + "/api/jwt/refresh"
-    response = requests.post(url, json={"refreshToken": refresh_token})
+    response = requests.post(url, json={"refreshToken": refresh_token}, timeout=30)
     if response.status_code != 200:
-        raise ValueError("Invalid refresh token please run soil login again.")
+        raise errors.LoginError("Invalid refresh token please run soil login again.")
     return json.loads(response.text)["token"]
 
 
 def get_soil_root(relpath: str) -> Optional[str]:
-    """Checks if the current dir is under a soil environment and returns its root. Returns None otherwise."""
+    """Checks if the current dir is under a soil environment
+    and returns its root. Returns None otherwise."""
     path = os.path.abspath(relpath) + "/"
     while path != "/":
         path, _ = os.path.split(path)
@@ -38,7 +42,7 @@ if env != "test":
     try:
         if project_root is None:
             raise FileNotFoundError("Project root not found.")
-        with open(project_root + "/soil.conf", encoding='utf-8') as conf_file:
+        with open(project_root + "/soil.conf", encoding="utf-8") as conf_file:
             CONF = json.loads(conf_file.read())
             SOIL_URL = CONF["soil_url"]
         logging.info(
@@ -48,11 +52,13 @@ if env != "test":
         )
     except FileNotFoundError:
         try:
-            with open(getenv("HOME", "") + "/.soil/soil.conf", encoding='utf-8') as conf_file:
+            with open(
+                getenv("HOME", "") + "/.soil/soil.conf", encoding="utf-8"
+            ) as conf_file:
                 CONF = json.loads(conf_file.read())
                 SOIL_URL = CONF["soil_url"]
             logging.warning(
-                "Loaded config from %s using app_id %s. It is recommended to have a soil.conf file at the root of the project.", # NOQA pylint:disable=line-too-long
+                "Loaded config from %s using app_id %s. It is recommended to have a soil.conf file at the root of the project.",  # NOQA pylint:disable=line-too-long
                 getenv("HOME", "") + "/.soil/soil.conf",
                 CONF["auth_app_id"],
             )
@@ -69,17 +75,23 @@ TOKEN = ""  # nosec
 if env != "test":
     try:
         with open(
-            getenv("HOME", "") + "/.soil/" + CONF["auth_app_id"] + "/soil.env", encoding='utf-8'
+            getenv("HOME", "") + "/.soil/" + CONF["auth_app_id"] + "/soil.env",
+            encoding="utf-8",
         ) as env_file:
             ENV = json.loads(env_file.read())
             TOKEN = _refresh_token(CONF["auth_url"], ENV["auth"]["refreshToken"])
     except FileNotFoundError:
         logging.warning(
-            "~/.soil/%s/soil.env file not found. Using ~/.soil/soil.env instead. It is recommended to run soil login.",
+            (
+                "~/.soil/%s/soil.env file not found."
+                " Using ~/.soil/soil.env instead. It is recommended to run soil login."
+            ),
             CONF["auth_app_id"],
         )
         try:
-            with open(getenv("HOME", "") + "/.soil/soil.env", encoding='utf-8') as env_file:
+            with open(
+                getenv("HOME", "") + "/.soil/soil.env", encoding="utf-8"
+            ) as env_file:
                 ENV = json.loads(env_file.read())
                 TOKEN = _refresh_token(CONF["auth_url"], ENV["auth"]["refreshToken"])
         except FileNotFoundError:
@@ -98,7 +110,7 @@ if env != "test":
     token_app_id = decoded_token["applicationId"]
 
     if token_app_id != conf_app_id:
-        raise Exception(
+        raise errors.LoginError(
             "Application Id for the project config "
             + f"{conf_app_id} does not coincide with the token application id {token_app_id}.\n"
             + "Please, run 'soil login' again."
