@@ -1,4 +1,4 @@
-# pylint: disable=missing-docstring,no-self-use,line-too-long
+# pylint: disable=missing-docstring,line-too-long,import-error
 
 import unittest
 from unittest.mock import patch, call, MagicMock
@@ -21,8 +21,10 @@ class MockHttpResponse(NamedTuple):
 # pylint: disable=unused-argument
 def mock_http_post(
     url: str,
+    *,
     headers: Optional[Dict[str, str]] = None,
     json: Optional[Dict[str, str]] = None,
+    timeout: int
 ) -> MockHttpResponse:
     assert json is not None
     response = {"_id": "mock_id", "type": json["type"]}
@@ -31,7 +33,7 @@ def mock_http_post(
 
 # pylint: disable=unused-argument, too-many-return-statements
 def mock_http_get(
-    url: str, headers: Optional[Dict[str, str]] = None
+    url: str, *, headers: Optional[Dict[str, str]] = None, timeout: int
 ) -> MockHttpResponse:
     url_parts = urlparse(url)
     query_params = parse_qs(url_parts.query)
@@ -65,8 +67,8 @@ def mock_http_get(
     raise Exception("mock http case not found")
 
 
-@patch("soil.api.requests.get", side_effect=mock_http_get)
-@patch("soil.api.requests.post", side_effect=mock_http_post)
+@patch("soil.api.session.get", side_effect=mock_http_get)
+@patch("soil.api.session.post", side_effect=mock_http_post)
 class TestData(unittest.TestCase):
     def test_upload_data_object_list(
         self, mock_post: MagicMock, mock_get: MagicMock
@@ -80,13 +82,13 @@ class TestData(unittest.TestCase):
         assert data.pipeline is None
         mock_post.assert_called_once_with(
             "http://test_host.test/v2/results/",
-            headers={"Authorization": "Bearer test_token"},
             json={
                 "type": "soil.data_structures.predefined.list.List",
                 "data": "[1, 2, 3, 4]",
                 "metadata": None,
             },
-        )  # NOQA
+            timeout=30,
+        )
         assert mock_get.call_count == 0
 
     def test_upload_data_object_dict(
@@ -101,13 +103,13 @@ class TestData(unittest.TestCase):
         assert data.pipeline is None
         mock_post.assert_called_once_with(
             "http://test_host.test/v2/results/",
-            headers={"Authorization": "Bearer test_token"},
             json={
                 "type": "soil.data_structures.predefined.dict.Dict",
                 "data": '{"test": "dictionary", "value": 11}',
                 "metadata": None,
             },
-        )  # NOQA
+            timeout=30,
+        )
         assert mock_get.call_count == 0
 
     def test_upload_data_object_numpy(
@@ -122,13 +124,13 @@ class TestData(unittest.TestCase):
         assert data.pipeline is None
         mock_post.assert_called_once_with(
             "http://test_host.test/v2/results/",
-            headers={"Authorization": "Bearer test_token"},
             json={
                 "type": "soil.data_structures.predefined.ndarray.Ndarray",
                 "data": "[[1, 2], [3, 4]]",
                 "metadata": None,
             },
-        )  # NOQA
+            timeout=30,
+        )
         assert mock_get.call_count == 0
 
     def test_upload_data_object_pandas(
@@ -143,13 +145,13 @@ class TestData(unittest.TestCase):
         assert data.pipeline is None
         mock_post.assert_called_once_with(
             "http://test_host.test/v2/results/",
-            headers={"Authorization": "Bearer test_token"},
             json={
                 "type": "soil.data_structures.predefined.pd_data_frame.PdDataFrame",
                 "data": '{"col1":{"0":1,"1":2},"col2":{"0":3,"1":4}}',
                 "metadata": None,
             },
-        )  # NOQA
+            timeout=30,
+        )
         assert mock_get.call_count == 0
 
     def test_get_data_valid_id(self, mock_post: MagicMock, mock_get: MagicMock) -> None:
@@ -166,11 +168,11 @@ class TestData(unittest.TestCase):
             [
                 call(
                     "http://test_host.test/v2/states/?name=non_existing_alias_but_valid_id&with-roles",
-                    headers={"Authorization": "Bearer test_token"},
+                    timeout=30,
                 ),
                 call(
                     "http://test_host.test/v2/results/non_existing_alias_but_valid_id/",
-                    headers={"Authorization": "Bearer test_token"},
+                    timeout=30,
                 ),
             ]
         )
@@ -192,23 +194,23 @@ class TestData(unittest.TestCase):
             [
                 call(
                     "http://test_host.test/v2/states/?name=valid_alias&with-roles",
-                    headers={"Authorization": "Bearer test_token"},
+                    timeout=30,
                 ),
                 call(
                     "http://test_host.test/v2/states/alias_id/",
-                    headers={"Authorization": "Bearer test_token"},
+                    timeout=30,
                 ),
                 call(
                     "http://test_host.test/v2/results/non_existing_alias_but_valid_id/",
-                    headers={"Authorization": "Bearer test_token"},
+                    timeout=30,
                 ),
                 call(
                     "http://test_host.test/v2/states/?name=non_existing_alias_but_valid_id&with-roles",
-                    headers={"Authorization": "Bearer test_token"},
+                    timeout=30,
                 ),
                 call(
                     "http://test_host.test/v2/results/non_existing_alias_but_valid_id/",
-                    headers={"Authorization": "Bearer test_token"},
+                    timeout=30,
                 ),
             ]
         )
@@ -223,11 +225,11 @@ class TestData(unittest.TestCase):
             [
                 call(
                     "http://test_host.test/v2/states/?name=invalid_alias_invalidid&with-roles",
-                    headers={"Authorization": "Bearer test_token"},
+                    timeout=30,
                 ),
                 call(
                     "http://test_host.test/v2/results/invalid_alias_invalidid/",
-                    headers={"Authorization": "Bearer test_token"},
+                    timeout=30,
                 ),
             ]
         )
